@@ -159,7 +159,7 @@ from ae.kivy_glsl import ShaderIdType, ShadersMixin
 from ae.kivy_relief_canvas import ReliefCanvas                                                          # type: ignore
 
 
-__version__ = '0.3.34'
+__version__ = '0.3.37'
 
 
 # load/declared help/tour widgets, based-on Kivy core widgets (without any features from ae.kivy_app/widgets.kv)
@@ -935,7 +935,7 @@ class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
                     center_pos="lambda: list(map(float, layout.ids.next_but.center))",
                     shader_code="=plunge_waves",
                     time="lambda: -Clock.get_boottime()",
-                    tint_ink=(0.21, 0.39, 0.09, 0.9),
+                    tint_ink=[0.21, 0.39, 0.09, 0.9],
                 )),
                 ('tour_page_texts', dict(add_to='before')),
                 ('next_but', dict(
@@ -951,7 +951,7 @@ class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
                     center_pos="lambda: list(map(float, layout.ids.prev_but.center))",
                     shader_code="=plunge_waves",
                     time="lambda: -Clock.get_boottime()",
-                    tint_ink=(0.21, 0.39, 0.09, 0.9),
+                    tint_ink=[0.21, 0.39, 0.09, 0.9],
                 )),
                 ('tour_page_texts', dict(add_to='before')),
                 ('prev_but', dict(
@@ -968,7 +968,7 @@ class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
                     alpha="lambda: 0.12 + layout.ani_value / 3",
                     render_shape='RoundedRectangle',
                     shader_code='=worm_whole',
-                    tint_ink=(0.021, 0.039, 0.009, 0.9),
+                    tint_ink=[0.021, 0.039, 0.009, 0.9],
                 )),
                 ('prev_but', dict(
                     add_to='before',
@@ -989,14 +989,14 @@ class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
                     add_to='before',
                     render_shape='Ellipse',
                     shader_code='=fire_storm',
-                    tint_ink=(0.81, 0.39, 0.09, 0.39),
+                    tint_ink=[0.81, 0.39, 0.09, 0.39],
                     time="lambda: -Clock.get_boottime()",
                 )),
                 ('next_but', dict(
                     add_to='before',
                     render_shape='Ellipse',
                     shader_code='=fire_storm',
-                    tint_ink=(0.03, 0.03, 0.9, 0.39),
+                    tint_ink=[0.03, 0.03, 0.9, 0.39],
                 )),
             ),
             'responsible_layout': (
@@ -1017,13 +1017,13 @@ class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
                     add_to='before',
                     render_shape='Ellipse',
                     shader_code='=circled_alpha',
-                    tint_ink=(0.51, 0.39, 0.9, 0.999),
+                    tint_ink=[0.51, 0.39, 0.9, 0.999],
                 )),
                 ('next_but', dict(
                     add_to='before',
                     render_shape='Ellipse',
                     shader_code='=circled_alpha',
-                    tint_ink=(0.81, 0.39, 0.9, 0.999),
+                    tint_ink=[0.81, 0.39, 0.9, 0.999],
                 )),
             ),
             'tour_end': (
@@ -1031,13 +1031,13 @@ class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
                 ('prev_but', dict(
                     add_to='before',
                     render_shape='Ellipse',
-                    tint_ink=(0.51, 0.39, 0.9, 0.999),
+                    tint_ink=[0.51, 0.39, 0.9, 0.999],
                     time="lambda: -Clock.get_boottime()",
                 )),
                 ('next_but', dict(
                     add_to='before',
                     render_shape='Ellipse',
-                    tint_ink=(0.81, 0.39, 0.9, 0.999),
+                    tint_ink=[0.81, 0.39, 0.9, 0.999],
                 )),
             ),
         })
